# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .get_ip_set import *
from .get_regex_pattern_set import *
from .get_rule_group import *
from .get_web_acl import *
from .ip_set import *
from .regex_pattern_set import *
from .rule_group import *
from .web_acl import *
from .web_acl_association import *
from .web_acl_logging_configuration import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "aws:wafv2/ipSet:IpSet":
                return IpSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:wafv2/regexPatternSet:RegexPatternSet":
                return RegexPatternSet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:wafv2/ruleGroup:RuleGroup":
                return RuleGroup(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:wafv2/webAcl:WebAcl":
                return WebAcl(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:wafv2/webAclAssociation:WebAclAssociation":
                return WebAclAssociation(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:wafv2/webAclLoggingConfiguration:WebAclLoggingConfiguration":
                return WebAclLoggingConfiguration(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("aws", "wafv2/ipSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "wafv2/regexPatternSet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "wafv2/ruleGroup", _module_instance)
    pulumi.runtime.register_resource_module("aws", "wafv2/webAcl", _module_instance)
    pulumi.runtime.register_resource_module("aws", "wafv2/webAclAssociation", _module_instance)
    pulumi.runtime.register_resource_module("aws", "wafv2/webAclLoggingConfiguration", _module_instance)

_register_module()
